==> huaweicloudsdkoctopus-3.1.80-py2.py3-none-any.whl: huaweicloudsdkoctopus/v2/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

from huaweicloudsdkoctopus.v2.octopus_client import OctopusClient
from huaweicloudsdkoctopus.v2.octopus_async_client import OctopusAsyncClient

from huaweicloudsdkoctopus.v2.model.create_sim_sm_maps_request import CreateSimSmMapsRequest
from huaweicloudsdkoctopus.v2.model.create_sim_sm_maps_response import CreateSimSmMapsResponse
from huaweicloudsdkoctopus.v2.model.create_sim_sm_scenarios_files_request import CreateSimSmScenariosFilesRequest
from huaweicloudsdkoctopus.v2.model.create_sim_sm_scenarios_files_response import CreateSimSmScenariosFilesResponse
from huaweicloudsdkoctopus.v2.model.create_sim_sm_scenarios_request import CreateSimSmScenariosRequest
from huaweicloudsdkoctopus.v2.model.create_sim_sm_scenarios_response import CreateSimSmScenariosResponse
from huaweicloudsdkoctopus.v2.model.family_enum import FamilyEnum
from huaweicloudsdkoctopus.v2.model.file_create_req_srlz import FileCreateReqSrlz
from huaweicloudsdkoctopus.v2.model.file_create_srlz import FileCreateSrlz
from huaweicloudsdkoctopus.v2.model.file_nested_create_req_srlz import FileNestedCreateReqSrlz
from huaweicloudsdkoctopus.v2.model.label_brief_srlz import LabelBriefSrlz
from huaweicloudsdkoctopus.v2.model.list_sim_sm_scenarios_request import ListSimSmScenariosRequest
from huaweicloudsdkoctopus.v2.model.list_sim_sm_scenarios_response import ListSimSmScenariosResponse
from huaweicloudsdkoctopus.v2.model.map_create_req_srlz import MapCreateReqSrlz
from huaweicloudsdkoctopus.v2.model.map_version_enum import MapVersionEnum
from huaweicloudsdkoctopus.v2.model.mutable_file_srlz import MutableFileSrlz
from huaweicloudsdkoctopus.v2.model.patched_file_detail_srlz import PatchedFileDetailSrlz
from huaweicloudsdkoctopus.v2.model.post_response import PostResponse
from huaweicloudsdkoctopus.v2.model.post_response_field import PostResponseField
from huaweicloudsdkoctopus.v2.model.priority_enum import PriorityEnum
from huaweicloudsdkoctopus.v2.model.scenario_create_req_srlz import ScenarioCreateReqSrlz
from huaweicloudsdkoctopus.v2.model.scenario_list_srlz import ScenarioListSrlz
from huaweicloudsdkoctopus.v2.model.scenario_status_enum import ScenarioStatusEnum
from huaweicloudsdkoctopus.v2.model.scenario_version_enum import ScenarioVersionEnum
from huaweicloudsdkoctopus.v2.model.simulator_enum import SimulatorEnum
from huaweicloudsdkoctopus.v2.model.update_sim_sm_maps_files_request import UpdateSimSmMapsFilesRequest
from huaweicloudsdkoctopus.v2.model.update_sim_sm_maps_files_response import UpdateSimSmMapsFilesResponse
from huaweicloudsdkoctopus.v2.model.update_sim_sm_scenarios_files_request import UpdateSimSmScenariosFilesRequest
from huaweicloudsdkoctopus.v2.model.update_sim_sm_scenarios_files_response import UpdateSimSmScenariosFilesResponse

==> huaweicloudsdkoctopus-3.1.154-py2.py3-none-any.whl: huaweicloudsdkoctopus/v2/__init__.py <==
# coding: utf-8

from __future__ import absolute_import

from huaweicloudsdkoctopus.v2.octopus_client import OctopusClient
from huaweicloudsdkoctopus.v2.octopus_async_client import OctopusAsyncClient

from huaweicloudsdkoctopus.v2.model.batch_create_request import BatchCreateRequest
from huaweicloudsdkoctopus.v2.model.create_sim_batches_request import CreateSimBatchesRequest
from huaweicloudsdkoctopus.v2.model.create_sim_batches_response import CreateSimBatchesResponse
from huaweicloudsdkoctopus.v2.model.create_sim_sm_maps_request import CreateSimSmMapsRequest
from huaweicloudsdkoctopus.v2.model.create_sim_sm_maps_response import CreateSimSmMapsResponse
from huaweicloudsdkoctopus.v2.model.create_sim_sm_scenarios_files_request import CreateSimSmScenariosFilesRequest
from huaweicloudsdkoctopus.v2.model.create_sim_sm_scenarios_files_response import CreateSimSmScenariosFilesResponse
from huaweicloudsdkoctopus.v2.model.create_sim_sm_scenarios_request import CreateSimSmScenariosRequest
from huaweicloudsdkoctopus.v2.model.create_sim_sm_scenarios_response import CreateSimSmScenariosResponse
from huaweicloudsdkoctopus.v2.model.family_enum import FamilyEnum
from huaweicloudsdkoctopus.v2.model.file_create_req_srlz import FileCreateReqSrlz
from huaweicloudsdkoctopus.v2.model.file_create_srlz import FileCreateSrlz
from huaweicloudsdkoctopus.v2.model.file_nested_create_req_srlz import FileNestedCreateReqSrlz
from huaweicloudsdkoctopus.v2.model.label_brief_srlz import LabelBriefSrlz
from huaweicloudsdkoctopus.v2.model.list_sim_simulations_request import ListSimSimulationsRequest
from huaweicloudsdkoctopus.v2.model.list_sim_simulations_response import ListSimSimulationsResponse
from huaweicloudsdkoctopus.v2.model.list_sim_sm_scenarios_request import ListSimSmScenariosRequest
from huaweicloudsdkoctopus.v2.model.list_sim_sm_scenarios_response import ListSimSmScenariosResponse
from huaweicloudsdkoctopus.v2.model.map_create_req_srlz import MapCreateReqSrlz
from huaweicloudsdkoctopus.v2.model.map_version_enum import MapVersionEnum
from huaweicloudsdkoctopus.v2.model.mutable_file_srlz import MutableFileSrlz
from huaweicloudsdkoctopus.v2.model.patched_file_detail_srlz import PatchedFileDetailSrlz
from huaweicloudsdkoctopus.v2.model.post_response import PostResponse
from huaweicloudsdkoctopus.v2.model.post_response_field import PostResponseField
from huaweicloudsdkoctopus.v2.model.priority_enum import PriorityEnum
from huaweicloudsdkoctopus.v2.model.scenario_create_req_srlz import ScenarioCreateReqSrlz
from huaweicloudsdkoctopus.v2.model.scenario_list_srlz import ScenarioListSrlz
from huaweicloudsdkoctopus.v2.model.scenario_status_enum import ScenarioStatusEnum
from huaweicloudsdkoctopus.v2.model.scenario_version_enum import ScenarioVersionEnum
from huaweicloudsdkoctopus.v2.model.show_sim_simulations_files_request import ShowSimSimulationsFilesRequest
from huaweicloudsdkoctopus.v2.model.show_sim_simulations_files_response import ShowSimSimulationsFilesResponse
from huaweicloudsdkoctopus.v2.model.simulation_eva_result_metric_srlz import SimulationEvaResultMetricSrlz
from huaweicloudsdkoctopus.v2.model.simulation_eva_result_srlz import SimulationEvaResultSrlz
from huaweicloudsdkoctopus.v2.model.simulation_evaluation_metric_srlz import SimulationEvaluationMetricSrlz
from huaweicloudsdkoctopus.v2.model.simulation_evaluation_srlz import SimulationEvaluationSrlz
from huaweicloudsdkoctopus.v2.model.simulation_file_path_srlz import SimulationFilePathSrlz
from huaweicloudsdkoctopus.v2.model.simulation_srlz import SimulationSrlz
from huaweicloudsdkoctopus.v2.model.status15e_enum import Status15eEnum
from huaweicloudsdkoctopus.v2.model.update_sim_sm_maps_files_request import UpdateSimSmMapsFilesRequest
from huaweicloudsdkoctopus.v2.model.update_sim_sm_maps_files_response import UpdateSimSmMapsFilesResponse
from huaweicloudsdkoctopus.v2.model.update_sim_sm_scenarios_files_request import UpdateSimSmScenariosFilesRequest
from huaweicloudsdkoctopus.v2.model.update_sim_sm_scenarios_files_response import UpdateSimSmScenariosFilesResponse
